/*
 * See the NOTICE file distributed with this work for additional
 * information regarding copyright ownership.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.xwiki.eventstream.store.solr.internal;

import java.util.Arrays;
import java.util.HashSet;
import java.util.Set;

import javax.inject.Named;
import javax.inject.Singleton;

import org.xwiki.component.annotation.Component;
import org.xwiki.eventstream.Event;
import org.xwiki.search.solr.AbstractSolrCoreInitializer;
import org.xwiki.search.solr.SolrException;

/**
 * Initialize the Solr core dedicated to events storage.
 * 
 * @version $Id: 29ace26d8f212cc8fc10e13ed4095a07aa087fee $
 * @since 12.4RC1
 */
@Component
@Named(EventsSolrCoreInitializer.NAME)
@Singleton
public class EventsSolrCoreInitializer extends AbstractSolrCoreInitializer
{
    /**
     * The name of the core.
     */
    public static final String NAME = "events";

    /**
     * @see org.xwiki.eventstream.Event#getParameters()
     */
    public static final String SOLR_FIELD_PROPERTIES = "properties";

    /**
     * The name of the field containing the list of users having this event in its inbox in read state.
     */
    public static final String SOLR_FIELD_READLISTENERS = "readListeners";

    /**
     * The name of the field containing the list of users having this event in its inbox in unread state.
     */
    public static final String SOLR_FIELD_UNREADLISTENERS = "unreadListeners";

    /**
     * The known fields.
     */
    public static final Set<String> KNOWN_FIELDS = new HashSet<>(
        Arrays.asList(SOLR_FIELD_ID, Event.FIELD_GROUPID, Event.FIELD_DATE, Event.FIELD_IMPORTANCE, Event.FIELD_TITLE,
            Event.FIELD_BODY, Event.FIELD_APPLICATION, Event.FIELD_STREAM, Event.FIELD_TYPE, Event.FIELD_WIKI,
            Event.FIELD_SPACE, Event.FIELD_DOCUMENT, Event.FIELD_DOCUMENTVERSION, Event.FIELD_RELATEDENTITY,
            Event.FIELD_USER, Event.FIELD_URL, Event.FIELD_DOCUMENTTITLE, Event.FIELD_TARGET, Event.FIELD_HIDDEN));

    @Override
    protected long getVersion()
    {
        return SCHEMA_VERSION_12_3;
    }

    @Override
    protected void createSchema() throws SolrException
    {
        addStringField(Event.FIELD_GROUPID, false, false);
        addPDateField(Event.FIELD_DATE, false, false);
        addStringField(Event.FIELD_IMPORTANCE, false, false);
        addStringField(Event.FIELD_TITLE, false, false);
        addStringField(Event.FIELD_BODY, false, false);
        addStringField(Event.FIELD_APPLICATION, false, false);
        addStringField(Event.FIELD_STREAM, false, false);
        addStringField(Event.FIELD_TYPE, false, false);
        addStringField(Event.FIELD_WIKI, false, false);
        addStringField(Event.FIELD_SPACE, false, false);
        addStringField(Event.FIELD_DOCUMENT, false, false);
        addStringField(Event.FIELD_DOCUMENTVERSION, false, false);
        addStringField(Event.FIELD_RELATEDENTITY, false, false);
        addStringField(Event.FIELD_USER, false, false);
        addStringField(Event.FIELD_URL, false, false);
        addStringField(Event.FIELD_DOCUMENTTITLE, false, false);
        addStringField(Event.FIELD_TARGET, true, false);
        addBooleanField(Event.FIELD_HIDDEN, false, false);

        addStringField(SOLR_FIELD_READLISTENERS, true, false);
        addStringField(SOLR_FIELD_UNREADLISTENERS, true, false);

        addMapField(SOLR_FIELD_PROPERTIES);
    }

    @Override
    protected void migrateSchema(long cversion)
    {
        // No migration needed yet
    }
}
